bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 4. Aventiure
___________________________________________________ #### Aventivre wie sivrit #### mit den sahsen streit
###### 139 | ### Nu nahten vremdiv maere | in gvnthers lant ### von boten di in verre | wurden dar gesant ### von vnchvnden rechen | di in trvogen haz ### do si die rede vernamen | leit was in waerliche daz
###### 140 | ### die wil ich iv nennen | ez was livdeger ### vzer sahsenlande | ein richer fvrste her ### vnt ovch von tenemarche | der kvnec livdegast ### die brahten in ir reise | vil manegn herlichn gast
###### 141 | ### ir boten chomn waren | in gvnthers lant ### di sine widerwinnen | waren dar gesant ### do vraget man der maere | di vnchvnden man ### man hiez di boten balde | ce hove fvr den kvnec gan
###### 142 | ### der grvozte si vil scone | er sprach sit willechomn ### wer ivch her hab gesendent | desn han ich niht vernomn ### daz svlt ir lazen hoeren | sprach der kvnec gvot ### do vorhten si vil sere | den grimmen gvnthers mvot
###### 143 | ### welt ir kvnec erlovben | daz wir iv maere sagn ### div wir iv da bringen | so ne svl wir niht verdagn ### wir nennen iv di herren | di vns her habent gesant ### livdgast vnd livdger | di wellent svochen her enlant
###### 144 | ### ir habt ir zorn verdienet | ia horten wir wol daz ### daz iv di herrn beide | tragent grozen haz ### si wellent herverten | ce wormez an den rin ### in hilfet vil der degene | daz wizzet vf di triwe min
###### 145 | ### inre zwelf wochen | div reise mvoz gescehn ### habt ir iht gvoter friwende | daz lazet balde sehn ### di iv vriden helfen | di bvrge vnt iwer lant ### hie wirt von in verhovwen | vil manec helm vnd rant
###### 146 | ### oder welt ir mit in dingen | so enbietet ez in dar ### so ne ritent iv so nahen | niht die manegen scar ### der iwer starchen viende | vf hercenlichiv leit ### davon verderben mvezen | vil gvote riter gemeit
###### 147 | ### nv bitet eine wile | sprach der kvnec gvot ### vnz ich mich baz versinne | ich chvend iv minen mvot ### han ich getriwer iemen | di ne sol ich niht verdagn ### disiv starchen maere | sol ich minen friwenden chlagn
###### 148 | ### gvnthere dem vil richen | wart leide genvoch ### di rede er tovgenlichen | in sime hercen trvoch ### er hiez gewinnen hagenen | vnt ander sine man ### vnt bat ovch harte balde | ce hove nach gernote gan
###### 149 | ### do chomen di bestn | swaz man der da vant ### er sprach man wil vns svochen | her in vnser lant ### mit starchen herverten | daz lat iv wesen leit ### des antwurte gernot | ein riter chven vnt gemeit
###### 150 | ### daz wer et wir mit swerten | so sprach gernot ### da sterbent wan di veigen | di lazen ligen tot ### darvmb ich niht vergezen | mach der eren min ### di vnsern viande | svln vns willechomn sin
###### 151 | ### do sprach von tronege hagne | daz en dvnchet mich niht gvot ### livdgast vnt livdger | di tragent vbermvot ### wir mvgen vns niht besenden | in so chvrcen tagn ### so sprach der chvene reche | wan mvgt irz sivride sagn
###### 152 | ### die boten herbergen | hiez man in di stat ### swie vient man in waere | vil scone ir pflegn bat ### gvnther der riche | daz was wol getan ### vnz er revant an friwenden | wer im da wolde gestan
###### 153 | ### dem kvnege in sinen sorgen | was idoch vil leit ### do sah in trvorende | ein riter vil gemeit ### der niht mohte wizzen | waz im was gescehen ### do bat er im der maere | den kvnec gvnther veriehen
###### 154 | ### mich nimt des michel wunder | sprach do sivrit ### wie habt ir so vercheret | di vroelichen sit ### der ir mit vns nv lange | habt alher gepflegn ### des antwurt im do gvnther | der vil cierliche degn
###### 155 | ### ia ne mag ich allen livten | di swaere niht gesagn ### di ich mvoz tovgenliche | in mime hercen tragn ### man sol staeten vriwenden | chlagen hercen not ### div sivrides varwe | wart do bleich vnd rot
###### 156 | ### er sprach zvo dem kvnege | ine han iv niht verseit ### ich sol iv helfen wenden | elliv iwer leit ### welt ir vriwent svochen | der sol ich einer sin ### vnt truowez wol volbringen | mit eren an daz ende min
###### 157 | ### nv lon iv got her sivrit | div rede dvnchet mich gvot ### vnt ob mir nimmer helfe | iwer ellen getvot ### ich frev mich doch der maere | daz ir mir sit so holt ### leb ich decheine wile | ez wirdet vmb ivch wol versolt
###### 158 | ### ich wil ivch lazen hoeren | warvmb ich trvorec stan ### von botn miner viende | ich daz vernomn han ### daz si mich wellen svochen | mit herverten hie ### daz getaten vns noch degene | her zvo disen landen nie
###### 159 | ### daz lat ivch ahten ringe | sprach do sivrit ### vnt senftet iwerem mvote | tvot des ich ivch bit ### lat mich iv erwerben | ere vnde frvmn ### vnt bittet iwer degene | daz si iv ovch ce helfe chvmn
###### 160 | ### swenne iwer starchen viende | zir helfe moehten han ### drizech tvsent degene | so wold ich si bestan ### vnt het ich niwan tvsent | des lat ivch an mich ### do sprach der kvnec gvnther | daz dien ich immer vm dich
###### 161 | ### so heizet mir gewinnen | tvsent iwer man ### sit daz ich der minen | bi mir niht en han ### niwan zwelf rechen | so wer ich iwer lant ### iv sol mit triwen dienen | immer sivrids hant
###### 162 | ### des sol vns helfen hagne | vnt ovch oertwin ### danchwart vnd sindolt | di liebn rechen din ### ovch sol damit riten | volker der chvene man ### der sol den vanen fveren | baz ichs niemn en gan
###### 163 | ### vnt lat di boten riten | heim in ir herrn lant ### daz si vns sehen sciere | daz tvo man in bechant ### so daz vnser bverge | mvezen vride han ### do hiez der kvnec besenden | beide mage vnd man
###### 164 | ### die boten livdegers | ce hove giengen do ### daz si ce lande solden | des waren si vil vro ### do bot in riche gabe | gvnther der kvnec gvot ### vnt scvof in sin geleite | des stvont in hohe der mvot
###### 165 | ### nv sagt sprach do gvnther | den starchen vienden min ### si mvgen mit ir reise | wol da heime sin ### welln aber si mich svochen | her in miniv lant ### mirn cerinne miner vriwende | in wirt arbeit erchant
###### 166 | ### den boten riche gabe | man do fver trvoch ### der het in ce gebene| gvnther genvoch ### di ne torsten versprech | di livdgers man ### do si vrlovp genamen | si schieden vroeliche dan
###### 167 | ### do di boten warn | ce tenemarche chomn ### vnt der kvnec livdgast | hete daz vernomn ### wie si von rine chomn | als im daz wart geseit ### ir starchez vbermveten | daz was im waerlichen leit
###### 168 | ### si sagten daz si heten | vil manegen chvenen man ### ovch sahen si darvnder | einen rechen stan ### der was geheizen sivrit | ein helt vz niderlant ### ez leidete livdegaste | als er daz maere rehte ervant
###### 169 | ### do di von tenemarche | dizze horten sagn ### do ilten si der friwente | deste mer beiagn ### vnz daz her livdegast | siner chvenen man ### zweinzech tvsent degene | zvo siner reise gewan
###### 170 | ### do besant ovch sich von sachsen | der kvnec livdger ### vnze si vierzech tvsent | heten vnde mer ### mit den si wolden riten | in bvrgonden lant ### do het ovch sich hie heime | der chvnech gvnther besant
###### 171 | ### mit den sinen magen | vnt siner brvoder man ### die si wolden fveren | dvrch vrlivge dan ### vnt ovch di hagenen rechen | des gie den helden not ### darvmbe mvosen degene | sider chiesen den tot
###### 172 | ### si vlizzen sich der reise | do si wolden dan ### den vanen mvose leiten | volker der chvene man ### also si wolden riten | von wormez vber rin ### hagene von tronege | der mvose scarmeister sin
###### 173 | ### damite reit ovch sindolt | vnd hvonolt ### di wol gedienen chvnden | daz gvnthers golt ### danchwart hagenen brvoder | vnt ovch oertwin ### di mohten wol mit ern | in der herverte sin
###### 174 | ### her kvnec nv sit hie heime | sprach do sivrit ### sit daz iwer rechen | mir wellent volgen mit ### belibet bi den frovwen | vnt traget hohen mvot ### ich truowe iv wol behveten | beidiv ere vnde gvot
###### 175 | ### die ivch da wolden svochen | ce wormez an den rin ### daz wil ich wol behveten | si mvegen da heime sin ### wir svlen in geriten | so nahen in ir lant ### daz in ir vbermveten | werde in sorgn erwant
###### 176 | ### von rine si dvrch hessen | mit ir helden riten ### gegen sahsenlande | da wart sit gestriten ### mit rovbe vnt ovch mit brande | wuosten si daz lant ### daz ez den fversten beiden | wart mit arbeit bechant
###### 177 | ### si chomen vf di marche | di chnehte zogten dan ### sivrit der vil starche | vragen des began ### wer sol des gesindes | vns nv hveten hie ### ia ne wart den sahsen | geriten schedlicher nie
###### 178 | ### si sprachen lat di tvmben | hveten vf den wegn ### den chvenen danchwarten | der ist ein sneller degn ### wir vliesen deste minre | von livdgers man ### lat in vnt oertewinen | hie di nahhvote han
###### 179 | ### so wil ich selbe riten | sprach sivrit der degen ### vnt wil der warte | gegen den vienden pflegn ### vnz ich rehte ervinde | wa di rechen sint ### do wart gewafent sciere | der scoenen siglinden chint
###### 180 | ### daz volch bevalch er hagenen | do er wolde dan ### vnt gernote | dem vil chvenen man ### do reit er eine dannen | in der sahsen lant ### des wart von im verhovwen | des tages manech helmbant
###### 181 | ### do sah er her daz groze | daz vf dem velde lach ### daz wider siner helfe | mit vnfvoge wach ### des was wol viercech tvsent | oder dannoch baz ### sivrit in hohem mvote | sach vil vroeliche daz
###### 182 | ### do het ovch sich ein reche | gein den vienden dar ### erhaben vf di warte | der was ce vlize gar ### den sach der herre sivrit | vnt in der chvene man ### ietweder do des andern | mit nide hveten began
###### 183 | ### ich sag iv wer der waere | der der warte pflach ### ein liehter scilt von golde | im vor der hende lach ### ez was der kvnec livdegast | der hvote siner schar ### dirre gast vil edele | spranchte vil herlichen dar
###### 184 | ### nv het ovch in her livdgast | vientlich erchorn ### ir ross si namen beide | cen siten mit den sporn ### si neigten vf di scilde | di scefte mit ir chraft ### des wart der kvnec riche | mit grozen sorgen behaft
###### 185 | ### div ross nach stiche trvogen | div richen kvnges kint ### beide fvr einander | sam si waete ein wint ### mit zovmen wart gewendet | vil riterliche dan ### mit swerten ez versvochten | die zwene grimmige man
###### 186 | ### do slvoch der herre sivrit | daz al daz velt erdoz ### do stovb vz dem helme | sam von brenden groz ### die viwerroten vanchen | von des heldes hant ### ir ietweder den sinen | an dem andern vant
###### 187 | ### ovch slvg im her livdgast | vil manegen grimmen slach ### ir ietweders ellen | vf schilden vaste lach ### do heten dar gehvetet | wol drizech siner man ### e daz im di choemen | den sig doch sivrit gewan
###### 188 | ### mit drien starchen wunden | di er dem kvnge slvoch ### dvrch eine wize brvnne | div was gvot genvoch ### daz swert an sinen ekken | braht vz wunden blvot ### des mvose der kvnec livdegast | habn trvorigen mvot
###### 189 | ### er bat sich lebn lazen | vnt bot im siniv lant ### vnt sagt im daz er waere | livdegast genant ### do chomen sine rechen | di heten wol gesehen ### waz da von in beiden | vf der warte was gescehn
###### 190 | ### er wolde in fveren dannen | do wart er angerant ### von drizech sinen mannen | do werte des heldes hant ### sinen richen gisel | mit vngefvegen slegen ### sit tet scaden mere | der vil zierliche degen
###### 191 | ### die drizech er ce tode | vil werliche slvoch ### er liez ir lebn einen | balde er reit genvoch ### vnt sagte hin div maere | waz hie was gescehen ### ovch mohte mans der warheit | an sime rotem helme sehen
###### 192 | ### den von tenemarche | was vil grimme leit ### ir herre was gevangen | do in daz wart geseit ### man sagt ez sinem brvoder | toben er began ### von vngefvegem zorne | wand im was leide getan
###### 193 | ### livdegast der reche | was gefveret dan ### von sivrids gewalte | zvo gvnthers man ### er bevalch in hagenen | do in daz wart geseit ### daz ez der kvnech waere | do was in maezliche leit
###### 194 | ### man hiez den bvrgonden | ir vanen binden an ### wol vf sprach sivrit | hie wirt mer getan ### e sich der tach verende | sol ich habn den lip ### daz mvot in sahsenlande | vil manech waetlichez wip
###### 195 | ### ir helde von dem rine | ir svlt min nemn war ### ich chan ivch wol geleiten | in livdegers scar ### so seht ir helme hovwen | von gvoter helde hant ### e daz wir wider wenden | iv wirdet sorge bechant
###### 196 | ### cen rossen gahte gernot | vnt sine man ### den vanen zvchte balde | der starche spileman ### volker der herre | do reit er vor der scar ### do was ovch daz gesinde | ce strite herlichen gar
###### 197 | ### si fvorten doch niht mere | niwan tvsent man ### darvber zwelf rechen | stieben do began ### di molten von den strazen | si riten vber lant ### da sah man von in scinen | vil manegen herlichen rant
###### 198 | ### do waren ovch di sahsen | mit ir scharn chomn ### mit swerten wol gewachsen | daz han ich sit vernomn ### div swert div sniten sere | den helden an der hant ### do wolden si den gestn | weren bverge vnd lant
###### 199 | ### der herrn scarmeister | daz volch do fvorte dan ### do was ovch chomn sivrit | mit den sinen man ### di er mit im brahte | vzer niderlant ### des tages wart in stvrme | vil manech plvotigiv hant
###### 200 | ### sindolt vnd hvnolt | vnt ovch gernot ### di slvogn in dem strite | vil manegen helt tot ### e si daz reht erfvnden | wie chvene was ir lip ### daz mvose sit beweinen | vil manech edel wip
###### 201 | ### volker vnd hagne | vnt ovch oertwin ### di lascten ime strite | vil maneges helmes schin ### mit vliezendem blvote | di stvormchvene man ### da wart von danchwarte | vil michel wunder getan
###### 202 | ### die von tenemarche | versvochten wol ir hant ### do horte man von hvrte | erdiezen manegen rant ### vnt ovch von scaerpfen swerten | der man da vil geslvoch ### di stritchvenen sahsen | taten scaden da genvoch
###### 203 | ### do di von bvrgonden | drvngen in den strit ### von in wart erhovwen | vil manech wunde wit ### do sah man vber saetele | fliezen daz blvot ### svs wurben nach den eren | di riter chvene vnde gvot
###### 204 | ### man horte da lvote erhellen | den helden an der hant ### div vil scarpfen wafen | do di von niderlant ### drvngen nach ir herren | in di herten scar ### si chomn degenliche | mit samt sivride dar
###### 205 | ### volgen der von rine | niemn man im sach ### man mohte chiesen vliezen | den blvtigen bach ### dvrch di liehten helme | von sivrids hant ### vnz er livdegern | vor sinen hergesellen vant
###### 206 | ### dri widerchere | het er nv genomn ### dvrch daz her anz ende | nv was hagene chomn ### der half im wol ervollen | in stvorme sinen mvot ### des tages mvose ersterben | vor in manech riter gvot
###### 207 | ### do der starche livdger | sivriden vant ### vnt daz er alse hohe | trvog an siner hant ### den gvoten balmvngen | vnt ir so manegen slvoch ### des wart der herre zornech | vnt grimmich genvoch
###### 208 | ### do wart ein michel dringen | vnt grozer swerte chlanch ### da ir ingesinde | zvo zeinander dranch ### do versvochten sich di rechen | beide deste baz ### di scar begvnden wichen | sich hvop da groezlicher haz
###### 209 | ### dem vogte von den sahsen | was daz wol geseit ### sin brvoder was gevangen | daz was im harte leit ### wol wesser daz ez taete | daz siglinde chint ### man zeh ez gernote | vil wol ervant erz sint
###### 210 | ### di slege livdegers | di waren also starch ### daz sivride vnder saetele | strvochte daz march ### do sich daz ross erholte | der chvene sivrit ### der gewan in dem stvrme | einen vreislichen sit
###### 211 | ### des half im wol hagene | vnt ovch gernot ### danchwart vnt volker | des lag ir vil da tot ### sindolt vnt hvnolt | vnt oertwin der degen ### di chvnden in dem strite | cem tode manegen niderlegen
###### 212 | ### in stvrme vngesceiden | waren di fvrsten her ### do sach man vber helme | vligen manegen ger ### dvrch di liehten schilde | von der helde hant ### man sah da var nach blvote | vil mangen herlichen rant
###### 213 | ### in dem starchen stvrme | erbeizte manech man ### nider von den rossen | einander liefen an ### sivrit der vil chvene | vnt ovch livdeger ### man sach da scefte vliegen | vnd manegen scaerpfen ger
###### 214 | ### dvo flovch daz schiltgespenge | von sivrids hant ### den sig gedaht erwerben | der helt von niderlant ### an den chvenen sahsen | der man vil wunder sach ### hei waz da liehter ringe | der chvene danchwart cebrach
###### 215 | ### do het der herre livdeger | vf eime schilde erchant ### gemalet eine chrone | vor sivrids hant ### wol wesser er daz ez waere | der chreftige man ### der helt zvo sinen friwenden | do lvote rvefen began
###### 216 | ### gelovbet ivch des stvrmes | alle mine man ### svn den sigmvndes | ich hie gesehn han ### sivriden den starchen | han ich hie bechant ### in hat der vbele tivuel | her cen sahsen gesant
###### 217 | ### die vanen hiez er lazen | in dem stvrme nider ### vrides er do gerte | des werte man in sider ### doch mvos er werden gisel | in gvnthers lant ### daz het an im betwungen | des chvenen sivrides hant
###### 218 | ### mit gemeinem rate | so liezen si den strit ### dvrchel vil der helme | vnd ovch der schilde wit ### si leiten von den handen | swaz so man der vant ### di trvogen blvotes varwe | von der bvrgonden hant
###### 219 | ### si viengen swen si wolden | des heten si gewalt ### gernot vnd hagene | di rechen vil balt ### die wunden hiezen baren | si fvorten mit in dan ### gevangen zvo dem rine | fvnf hvndert werlicher man
###### 220 | ### die sigelosen rechen | ce tenemarche riten ### do ne heten ovch di sahsen | so hohe niht gestriten ### daz man in lobes iaehe | daz was den helden leit ### do wurden ovch di veigen | von vriwenden sere gechleit
###### 221 | ### si hiezen daz gewafen | wider sovmen an den rin ### ez hete wol geworben | mit den helden sin ### sivrit der reche | der hetez gvot getan ### des im iehen mvosen | alle gvnthers man
###### 222 | ### gegen wormez sande | der herre gernot ### heim zvo sime lande | den friwenden er enbot ### wie gelvngen waere | im vnt sinen man ### ez heten die vil chvenen | wol nach ern getan
###### 223 | ### die garzvone liefen | von den wart ez geseit ### da frevten sich vor liebe | di e da heten leit ### dirre lieben maere | di in da waren chomn ### da wart von edelen frovwen | michel vragen vernomn
###### 224 | ### wie gelvngen waere | des richen kvneges man ### man hiez der boten einen | fver chrimilde gan ### daz gescach vil tovgen | ia ne torstes vmber lvot ### wan si hete darvnder | ir vil liebez hercentrvot
###### 225 | ### do si den boten chomende | zir chemenaten sach ### chrimhilt div scoene | vil gvetlichen sprach ### nv sag an liebiv maere | ia gib ich dir min golt ### tvost dvz ane liegen | ich wil dir immer wesen holt
###### 226 | ### wie sciet vz dem strite | min brvoder gernot ### vnt ander mine friwenden | ist vns iht maneger tot ### oder wer tet da daz beste | daz solt dv mir sagn ### do sprach der bote sciere | wir heten ninder cheinen zagn
###### 227 | ### ze ernste vnt ce strite | reit niemn also wol ### vil edeliv kvneginne | sit ichz iv sagen sol ### so der gast vil edele | vzer niderlant ### da worhte michel wunder | des chvenen sivrides hant
###### 228 | ### swaz di rechen alle | in strite hant getan ### danchwart vnt hagene | vnt ander skvneges man ### swaz si striten nach ern | daz ist gar ein wint ### vnz eine an sivriden | des kvnec sigmvnds kint
###### 229 | ### si frvmten in dem stvrme | der helde vil erslagn ### doch moehte iv daz wunder | niemn wol gesagn ### waz da worhte sivrit | swen er ce strite reit ### den frovwen an ir magen | tet er div groezlichen leit
###### 230 | ### ovch mvoste da belibn | maneger frovwen trvt ### sine slege man horte | vf helmen also lvt ### daz si von wunden brahten | daz fliezende blvot ### erst an allen tvgenden | ein riter chven vnde gvot
###### 231 | ### swaz da hat begangen | von mecen oertwin ### swaz er ir moht erlangen | mit dem swerte sin ### di mvosen wunt belibn | oder meistech tot ### da tet iwer brvoder | die allergroezisten not
###### 232 | ### div immer in den stvermen | chvnde sin gescehn ### man mvoz der warheite | den vzerwelten iehn ### di stolcen bvrgonden | habent so gevaren ### daz si vor allen scanden | ir ere chvnnen wol bewarn
###### 233 | ### man sach da vor ir handen | vil manegen satel bloz ### da von liehten swerten | daz velt so lvote erdoz ### di rechen von dem rine | di habent so geriten ### daz ez ir vianden | waere bezer vermiten
###### 234 | ### die chvenen tronegaere | di frvmtn groziv leit ### do mit volches chreften | daz her cesamne reit ### da frvmte manegen toten | des chvenen hagenen hant ### des vil ce sagene waere | her ce bvrgonden lant
###### 235 | ### sindolt vnt hvnolt | di gernotes man ### vnt rvomolt der chvene | di hant so vil getan ### daz ez livdegere | mag immer wesen leit ### daz er den dinen magen | ze rine hete widerseit
###### 236 | ### strit den allerhoehsten | der inder da gescach ### ce ivngest vnt cem ersten | den ieman gesach ### den tet vil willechliche | div divrides hant ### er bringet riche gisel | in daz gvnthers lant
###### 237 | ### die twanch mit sinen ellen | der waetliche man ### des ovch der kvnec livdegast | mvoz den scaden han ### vnt ovch von sahsenlande | sin brvoder livdeger ### nv hoeret miniv maere | edeliv chvneginne her
###### 238 | ### si hat gevangen beide | div sivrids hant ### nie so manegen gisel | man braht in dizze lant ### so von sinen schvlden | nv chvmt an den rin ### ir chvnden disiv maere | nimmer lieber sin
###### 239 | ### man bringet der gesvnden | fvnf hvndert oder baz ### vnt der verchwunden | frovwe wizzet daz ### wol ahtzech rote bare | her in vnser lant ### di meistech hat verhovwen | des starchen sivrids hant
###### 240 | ### die dvrch vbermveten | widersagten an den rin ### di mvezen nv gevangen | di gvnthers sin ### die bringet man mit vrevden | her in dizze lant ### do erblvete ir liehtiv varwe | do si div maer reht ervant
###### 241 | ### ir scoenez antlvzze | daz wart rosenrot ### do mit liebe was gesceiden | vz der grozen not ### der waetliche reche | sivrit der ivnge man ### si frevte ovch sich ir friwende | daz was von scvlden getan
###### 242 | ### do sprach div minnechliche | dv hast mir wol geseit ### dv solt habn darvmbe | ce miete richiv chleit ### vnt zehen march von golde | die heiz ich dir tragn ### des mach man soelhiv mere | richen frovwen gerne sagn
###### 243 | ### man gab im sine miete | daz golt vnt ovch div chleit ### do gie an div venster | vil manec scoeniv meit ### si warten vf di strazen | riten man do vant ### vil der hochgemvoten | in der bvrgonden lant
###### 244 | ### da chomn die gesvnden | di wunden taten sam ### si mohten grvezen hoeren | von friwenden ane scam ### der wirt gein sinen gesten | vil vroeliche reit ### mit vrevden was verendet | daz sin vil groezliche leit
###### 245 | ### do enpfie er wol di sine | die vremden tet er sam ### wan dem richen kvnege | anders niht gezam ### wan danchen gvetliche | den di im waren chomn ### daz si den sig nah eren | in stvrme heten genomn
###### 246 | ### gvnther bat im maere | von sinen vriwenden sagn ### wer im an der reise | ce tode waer erslagn ### do het er vloren niemn | niwan sehzec man ### verchlagen man di mvose | so sit nach helden was getan
###### 247 | ### die gesvnden brahten | cerhovwen manegen rant ### von helme vil verscroten | in gvnthers lant ### daz volch erbeizte nidere | fvr des kvnges sal ### ce liebem antpfange | man horte vroelichen scal
###### 248 | ### do hiez man herbergen | di rechen in di stat ### der chvnech siner geste | vil scone pflegen bat ### er hiez der wunden hveten | vnt scaffen gvot gemach ### wol man sine tvgende | an sinen vianden sach
###### 249 | ### er sprach ce livdegaste | nv sit mir willechomn ### ich han von iwern scvlden | vil grozen scaden genomn ### der wirt mir nv vergolten | ob ich gelvcke han ### got lone minen vriwenden | si hant liebe getan
###### 250 | ### ir mvgt in gerne danchen | sprach do livdeger ### also hoher gisel | gewan nie kvnec mer ### vmbe scoene hvote | wir gebn michel gvot ### daz ir genaedechliche | an iwern vianden tvot
###### 251 | ### ich wil ivch beide lazen | sprach er ledech gen ### daz mine viande | hie bi mir besten ### des wil ich habn pvergen | daz si miniv lant ### iht rvemen ane hvlde | des bot livdeger di hant
###### 252 | ### man brahte si ce ruowe | vnt scvof in ir gemach ### den wunden man gebettet | vil gvetlichen sach ### man schancte den gesvnden | met vnt gvoten win ### do chvnde daz gesinde | nimmer vroelicher sin
###### 253 | ### ir cerhovwen schilde | behalten man do trvoch ### vil blvotiger saetele | der was da genvoch ### di hiez man verbergen | da weinten niht div wip ### da chom hermvede | maneges gvoten riters lip
###### 254 | ### der kvnec pflach siner geste | vil groezliche wol ### der vremden vnt der chvnden | div lant waren vol ### er bat der sere wunden | vil gvetliche pflegn ### do was ir vbermveten | vil harte ringe gelegn
###### 255 | ### die ercenie chvnden | den bot man richen solt ### silber ane wage | darzvo daz liehte golt ### daz si die helde nerten | nach der strites not ### darzvo der kvnec den gesten | gabe groezlichen bot
###### 256 | ### die wider heim ce hvse | heten reise mvot ### di bat man noch beliben | also man vriwenden tvot ### der kvnech do gie ce rate | wi er lonte sinen man ### si heten sinen willen | nach grozen ern getan
###### 257 | ### do sprach der herre gernot | man sol si riten lan ### vber sechs wochen | si in daz chvnt getan ### daz si chomn widere | ce einer hohgecit ### so ist ir maneger geheilet | der nv vil sere wunder lit
###### 258 | ### do gert ovch vrlovbes | sivrit von niderlant ### do der kvnec gvnther | den willen sin ervant ### er bat in minnechliche | noch bi im bestan ### niwan dvrch sine swester scoene | so ne waer ez nimmer getan
###### 259 | ### darzvo was er ce riche | daz er iht naeme solt ### er het daz wol verdienet | der kvnec was im holt ### sam waren sine mage | di heten daz gesehn ### waz von sinen chreften | in dem strite was gescehn
###### 260 | ### dvrch der scoenen willen | gedahter noch bestan ### ob er si gesehen moehte | sit wart ez getan ### wol nach sinen willen | wart im div maget bechant ### sit reit er vroeliche | in daz sigmvnds lant
###### 261 | ### der wirt hiez ce allen citen | riterscefte pflegn ### daz tet do willechlichen | vil manech ivnger degn ### di wile hiez er sideln | vor wormez vf den sant ### den di im chomn solden | zvo der bvrgonden lant
###### 262 | ### in den selbn citen | do si nv solden chomn ### do het div scoene chrimhilt | div maere wol vernomn ### er wolde hohgecite | dvrch liebe vriwende han ### do wart vil michel vlizen | von scoenen frovwen getan
###### 263 | ### mit waete vnt mit gebende | daz si da solden tragen ### vote div vil riche | div maere horte sagn ### von den stolzen rechen | di da solden chomn ### do wart vz der valde | vil richer chleider genomn
###### 264 | ### dvrch ir chinde liebe | hiez si bereiten chleit ### damite wart gecieret | vil manec frovwe vnt manech meit ### vnt vil der ivngen rechen | vz bvrgonden lant ### ovch hiez si vil den vremden | prveuen herlich gewant

<<< Übersicht <<< vorige Seite nächste Seite >>>